CloseTIMS: Close the TIMS data handle and release all resources.
Description
Calling this method is not mandatory - the resources will anyway
be cleanly released when the garbage collector decides to
destroy the OpenTIMS data handle. The only purpose of this
method is to enable them to be explicitly released earlier than that.